==> openGion6.8.0.0_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GEA10S.sql <==
/****************************************************************************/
/* GEA10 ( ﾕｰｻﾞｰ定義 )                                                      */
/*                                                                          */
/* Created : 2017/01/05 15:19:02                                            */
/****************************************************************************/

CREATE TABLE GEA10 (
   SYSTEM_ID    VARCHAR (  10 )                         NOT NULL                                                /*  10 ｼｽﾃﾑID           */
 , USERID       VARCHAR (  10 )                         NOT NULL                                                /*  20 ﾕｰｻﾞｰID          */
 , PASSWD       VARCHAR (  32 )                         NOT NULL                                                /*  30 ﾊﾟｽﾜｰﾄﾞ          */
 , LANG         VARCHAR (   2 )                         NOT NULL                                                /*  40 言語             */
 , NAME_JA      VARCHAR ( 200 )                                                                                 /*  50 名称             */
 , ROLES        TEXT                                                                                            /*  60 ﾛｰﾙｽﾞ            */
 , DROLES       TEXT                                                                                            /*  70 ﾃﾞｰﾀﾛｰﾙｽﾞ        */
 , COMMENTS     TEXT                                                                                            /*  80 ｺﾒﾝﾄ             */
 , DYPASSWD     VARCHAR (  14 )                                                                                 /*  90 ﾊﾟｽﾜｰﾄﾞ変更日時  */
 , DYVALID      VARCHAR (   8 )     DEFAULT '99999999'  NOT NULL                                                /* 100 有効日           */
 , FGDEFAULT    VARCHAR (   1 )     DEFAULT '0'                                                                 /* 110 ﾛｸﾞｲﾝFG          */
 , MAILAD       VARCHAR ( 100 )                                                                                 /* 120 ﾒｰﾙｱﾄﾞﾚｽ         */
 , UNIQ         BIGINT                                  NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ           */
 , FGJ          VARCHAR (   1 )     DEFAULT '1'         NOT NULL                                                /* 810 状態ﾌﾗｸﾞ         */
 , DYSET        VARCHAR (  14 )                                                                                 /* 820 登録日時         */
 , PGSET        VARCHAR (  10 )                                                                                 /* 830 作成PG           */
 , PGPSET       VARCHAR (  10 )                                                                                 /* 840 作成親PG         */
 , USRSET       VARCHAR (  10 )                                                                                 /* 850 作成社員         */
 , DYUPD        VARCHAR (  14 )                                                                                 /* 860 更新日時         */
 , PGUPD        VARCHAR (  10 )                                                                                 /* 870 更新PG           */
 , PGPUPD       VARCHAR (  10 )                                                                                 /* 880 更新親PG         */
 , USRUPD       VARCHAR (  10 )                                                                                 /* 890 更新者           */
);

==> openGion7.2.9.0_dev.zip: uap/webapps/ge/db/MYSQL/sql/install/01_TABLE/GEA10S.sql <==
/****************************************************************************/
/* GEA10 ( ﾕｰｻﾞｰ定義 )                                                      */
/*                                                                          */
/* Created : 2018/09/28 16:03:25                                            */
/****************************************************************************/

CREATE TABLE GEA10 (
   SYSTEM_ID    VARCHAR (  10 )                         NOT NULL                                                /*  10 ｼｽﾃﾑID           */
 , USERID       VARCHAR (  10 )                         NOT NULL                                                /*  20 ﾕｰｻﾞｰID          */
 , PASSWD       VARCHAR (  32 )                         NOT NULL                                                /*  30 ﾊﾟｽﾜｰﾄﾞ          */
 , LANG         VARCHAR (   2 )                         NOT NULL                                                /*  40 言語             */
 , NAME_JA      VARCHAR ( 200 )                                                                                 /*  50 名称             */
 , ROLES        TEXT                                                                                            /*  60 ﾛｰﾙｽﾞ            */
 , DROLES       TEXT                                                                                            /*  70 ﾃﾞｰﾀﾛｰﾙｽﾞ        */
 , COMMENTS     TEXT                                                                                            /*  80 ｺﾒﾝﾄ             */
 , DYPASSWD     VARCHAR (  14 )                                                                                 /*  90 ﾊﾟｽﾜｰﾄﾞ変更日時  */
 , DYVALID      VARCHAR (   8 )     DEFAULT '99999999'  NOT NULL                                                /* 100 有効日           */
 , FGDEFAULT    VARCHAR (   1 )     DEFAULT '0'                                                                 /* 110 ﾛｸﾞｲﾝFG          */
 , MAILAD       VARCHAR ( 100 )                                                                                 /* 120 ﾒｰﾙｱﾄﾞﾚｽ         */
 , UNIQ         BIGINT                                  NOT NULL    AUTO_INCREMENT  , PRIMARY KEY(UNIQ)         /* 800 ﾕﾆｰｸｷｰ           */
 , FGJ          VARCHAR (   1 )     DEFAULT '1'         NOT NULL                                                /* 810 状態ﾌﾗｸﾞ         */
 , DYSET        VARCHAR (  14 )                                                                                 /* 820 登録日時         */
 , PGSET        VARCHAR (  10 )                                                                                 /* 830 作成PG           */
 , PGPSET       VARCHAR (  10 )                                                                                 /* 840 作成親PG         */
 , USRSET       VARCHAR (  10 )                                                                                 /* 850 作成者           */
 , DYUPD        VARCHAR (  14 )                                                                                 /* 860 更新日時         */
 , PGUPD        VARCHAR (  10 )                                                                                 /* 870 更新PG           */
 , PGPUPD       VARCHAR (  10 )                                                                                 /* 880 更新親PG         */
 , USRUPD       VARCHAR (  10 )                                                                                 /* 890 更新者           */
);
